use axum::extract::Multipart;

use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    file_id: Uuid,
}

pub async fn modify(
    Query(params): Query<Params>,
    State(state): State<AppState>,
    claims: Claims,
    mut multipart: Multipart,
) -> GeneralResult<EmptyResponse> {
    db::file::get_permissions(params.file_id, claims.user_id, &state.pool)
        .await
        .can_write_guard()?;

    // Very weird work around to get the first file in multipart
    let mut field = loop {
        match multipart.next_field().await {
            Ok(Some(field)) if field.file_name().is_some() => break field,
            Ok(Some(_)) => continue,
            _ => {
                return Err(GeneralError::message(
                    StatusCode::BAD_REQUEST,
                    "No file in the multipart",
                ))
            }
        }
    };

    let mut file = state
        .storage
        .write(params.file_id)
        .await
        .handle_internal("Error writing to the file")?
        .item_not_found()?;

    let (hash, size) = crate::FileStorage::write_to_file(&mut file, &mut field)
        .await
        .map_err(|err| {
            tracing::warn!(%err);
            GeneralError::message(
                StatusCode::INTERNAL_SERVER_ERROR,
                "Error writing to the file",
            )
        })?;

    db::file::update(params.file_id, size, hash, &state.pool)
        .await
        .handle_internal("Error updating the file")?;

    Ok(EmptyResponse)
}
