use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    folder_id: Uuid,
}

pub async fn delete(
    State(state): State<AppState>,
    claims: Claims,
    Query(params): Query<Params>,
) -> GeneralResult<EmptyResponse> {
    let root = db::folder::get_root(claims.user_id, &state.pool)
        .await
        .handle_internal("Error getting the root folder")?;
    if params.folder_id == root {
        return Err(GeneralError::message(
            StatusCode::BAD_REQUEST,
            "Cannot delete the root folder",
        ));
    }

    db::folder::get_permissions(params.folder_id, claims.user_id, &state.pool)
        .await
        .can_write_guard()?;

    let storage = &state.storage;
    db::folder::delete(params.folder_id, &state.pool)
        .try_for_each_concurrent(5, |file| async move {
            let _ = storage.delete(file).await;
            Ok(())
        })
        .await
        .handle_internal("Error deleting the fodler")?;

    Ok(EmptyResponse)
}
