use tokio::try_join;

use crate::prelude::*;

#[derive(Debug, Deserialize)]
pub struct Params {
    pub(super) folder_id: Option<Uuid>,
}

#[derive(Debug, Serialize)]
pub struct Response {
    folder_id: Uuid,
    files: Vec<db::file::FileWithoutParentId>,
    folders: Vec<db::folder::FolderWithoutParentId>,
}

pub async fn list(
    Query(params): Query<Params>,
    State(pool): State<Pool>,
    claims: Claims,
) -> GeneralResult<Json<Response>> {
    let folder_id = db::folder::process_id(params.folder_id, claims.user_id, &pool)
        .await
        .handle_internal("Error processing id")?
        .handle(StatusCode::NOT_FOUND, "Item not found")?;

    let (files, folders) = try_join!(
        db::file::get_files(folder_id, &pool).try_collect(),
        db::folder::get_folders(folder_id, claims.user_id, &pool).try_collect()
    )
    .handle_internal("Error getting folder contents")?;

    Ok(Json(Response {
        folder_id,
        files,
        folders,
    }))
}
