use axum::Form;

use crate::{
    auth::{authenticate_user, Token},
    prelude::*,
};

#[derive(Deserialize, Debug)]
pub struct Params {
    username: String,
    password: String,
}

pub async fn login(
    State(pool): State<Pool>,
    Form(payload): Form<Params>,
) -> GeneralResult<Json<Token>> {
    let user_id = authenticate_user(&payload.username, &payload.password, &pool)
        .await
        .handle_internal("Error getting user from database")?
        .handle(
            StatusCode::NOT_FOUND,
            "User with this name and password doesn't exist",
        )?;
    Claims::new(user_id).encode().map(Json)
}
