use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    search_string: String,
}

pub async fn search(
    State(pool): State<Pool>,
    Query(params): Query<Params>,
) -> GeneralResult<Json<Vec<db::users::UserSearch>>> {
    db::users::search_for_user(&params.search_string, &pool)
        .take(20)
        .try_filter(|user| future::ready(user.similarity > 0.1))
        .try_collect()
        .await
        .handle_internal("Error getting users from the database")
        .map(Json)
}
